@@ -1,15 +1,38 @@
+/*
+ * Copyright (c) 2014-2017 Roy Keene
+ * 
+ * Permission is hereby granted, free of charge, to any person obtaining a 
+ * copy of this software and associated documentation files (the "Software"), 
+ * to deal in the Software without restriction, including without limitation 
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense, 
+ * and/or sell copies of the Software, and to permit persons to whom the 
+ * Software is furnished to do so, subject to the following conditions:
+ * 
+ * The above copyright notice and this permission notice shall be included in 
+ * all copies or substantial portions of the Software.
+ * 
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
+ * DEALINGS IN THE SOFTWARE.
+ */
 #define _LINUX_SOURCE 1
 #include <sys/resource.h>
 #include <sys/syscall.h>
 #include <sys/termios.h>
 #include <netinet/in.h>
 #include <sys/reboot.h>
+#include <sys/prctl.h>
 #include <arpa/inet.h>
 #include <sys/socket.h>
 #include <sys/select.h>
 #include <sys/mount.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
+#include <sys/timex.h>
 #include <sys/time.h>
 #include <sys/klog.h>
 #include <sys/swap.h>
@@ -935,6 +958,35 @@ static int tuapi_reboot(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *CO
 	return(TCL_OK);
 }
 
+static int tuapi_set_thread_name(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[]) {
+	char *name;
+
+	if (objc == 2) {
+#ifdef PR_SET_NAME
+		name = Tcl_GetString(objv[1]);
+		prctl(PR_SET_NAME, (unsigned long) name, 0, 0, 0);
+#else
+		Tcl_SetObjResult(interp, Tcl_NewStringObj("unsupported", -1));
+		return(TCL_ERROR);
+#endif
+	} else {
+#ifdef PR_GET_NAME
+		name = malloc(17);
+
+		prctl(PR_GET_NAME, (unsigned long) name, 0, 0, 0);
+
+		Tcl_SetObjResult(interp, Tcl_NewStringObj(name, -1));
+
+		free(name);
+#else
+		Tcl_SetObjResult(interp, Tcl_NewStringObj("unsupported", -1));
+		return(TCL_ERROR);
+#endif
+	}
+
+	return(TCL_OK);
+}
+
 static int tuapi_eject(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[]) {
 	Tcl_SetObjResult(interp, Tcl_NewStringObj("not implemented", -1));
 
@@ -2468,6 +2520,44 @@ static int tuapi_settimeofday(ClientData cd, Tcl_Interp *interp, int objc, Tcl_O
 	return(TCL_OK);
 }
 
+static int tuapi_adjtime(ClientData cd, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[]) {
+	struct timeval tv, oldTV;
+	Tcl_WideInt tv_sec_val, tv_usec_val;
+	int adjtime_ret, tcl_ret;
+
+	if (objc != 3) {
+		Tcl_SetObjResult(interp, Tcl_NewStringObj("wrong # args: should be \"::tuapi::syscall::adjtime seconds microseconds\"", -1));
+
+		return(TCL_ERROR);
+	}
+
+	tcl_ret = Tcl_GetWideIntFromObj(interp, objv[1], &tv_sec_val);
+	if (tcl_ret != TCL_OK) {
+		return(tcl_ret);
+	}
+
+	tcl_ret = Tcl_GetWideIntFromObj(interp, objv[2], &tv_usec_val);
+	if (tcl_ret != TCL_OK) {
+		return(tcl_ret);
+	}
+
+	tv.tv_sec = tv_sec_val;
+	tv.tv_usec = tv_usec_val; 
+
+	adjtime_ret = adjtime(&tv, &oldTV);
+
+	if (adjtime_ret != 0) {
+		Tcl_SetObjResult(interp, Tcl_NewStringObj(strerror(errno), -1));
+
+		return(TCL_ERROR);
+	}
+
+	/* XXX TODO: Return old adjustment */
+
+	return(TCL_OK);
+}
+
+
 #ifndef DISABLE_UNIX_SOCKETS
 struct tuapi_socket_unix__chan_id {
 	int fd;
@@ -3202,6 +3292,7 @@ int Tuapi_Init(Tcl_Interp *interp) {
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::domainname", tuapi_domainname, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::klogctl", tuapi_klogctl, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::settimeofday", tuapi_settimeofday, NULL, NULL);
+	Tcl_CreateObjCommand(interp, "::tuapi::syscall::adjtime", tuapi_adjtime, NULL, NULL);
 
 	/* Block or char device related commands */
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::losetup", tuapi_losetup, NULL, NULL);
@@ -3225,6 +3316,7 @@ int Tuapi_Init(Tcl_Interp *interp) {
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::execve", tuapi_execve, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::rlimit", tuapi_rlimit, NULL, NULL);
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::reboot", tuapi_reboot, NULL, NULL);
+	Tcl_CreateObjCommand(interp, "::tuapi::syscall::set_thread_name", tuapi_set_thread_name, NULL, NULL);
 
 	/* Network related commands */
 	Tcl_CreateObjCommand(interp, "::tuapi::syscall::ifconfig", tuapi_ifconfig, NULL, NULL);
@@ -3256,7 +3348,7 @@ int Tuapi_Init(Tcl_Interp *interp) {
 #include "tuapi.tcl.h" 
 	);
 
-	Tcl_PkgProvide(interp, "tuapi", "0.10");
+	Tcl_PkgProvide(interp, "tuapi", "0.12");
 
 	return(TCL_OK);
 }
