@@ -1,5 +1,25 @@
    "#! /usr/bin/env tclsh\n"
    "\n"
+   "# Copyright (c) 2014-2017 Roy Keene\n"
+   "# \n"
+   "# Permission is hereby granted, free of charge, to any person obtaining a \n"
+   "# copy of this software and associated documentation files (the \"Software\"), \n"
+   "# to deal in the Software without restriction, including without limitation \n"
+   "# the rights to use, copy, modify, merge, publish, distribute, sublicense, \n"
+   "# and/or sell copies of the Software, and to permit persons to whom the \n"
+   "# Software is furnished to do so, subject to the following conditions:\n"
+   "# \n"
+   "# The above copyright notice and this permission notice shall be included in \n"
+   "# all copies or substantial portions of the Software.\n"
+   "# \n"
+   "# THE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR \n"
+   "# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, \n"
+   "# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL \n"
+   "# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER \n"
+   "# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING \n"
+   "# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER \n"
+   "# DEALINGS IN THE SOFTWARE.\n"
+   "\n"
    "namespace eval ::tuapi {}\n"
    "namespace eval ::tuapi::helper {}\n"
    "namespace eval ::tuapi::cache {}\n"
